@@ -124,6 +124,7 @@ from sre_constants import (
 		LITERAL,
 		MAX_REPEAT,
 		MAXREPEAT,
+		MIN_REPEAT,
 		RANGE,
 		SUBPATTERN
 		)
@@ -412,7 +413,7 @@ class RegexParser:
 						buf.append(type(self).IN_COLOUR("]"))
 					continue
 
-				if what is MAX_REPEAT:
+				if what is MAX_REPEAT or what is MIN_REPEAT:
 					min_, max_, item = content
 					_parse_pattern(item)
 
@@ -432,8 +433,16 @@ class RegexParser:
 						buf.append(type(self).LITERAL_COLOUR(","))
 						buf.append(type(self).REPEAT_COLOUR(str(max)))
 						buf.append(type(self).REPEAT_BRACE_COLOUR("}"))
+					if what is MIN_REPEAT:
+						buf.append(type(self).REPEAT_COLOUR("?"))
 
 					continue
+				#
+				# if what is MIN_REPEAT:
+				# 	min_, max_, item = content
+				# 	_parse_pattern(item)
+				# 	print(min_, max_, item)
+				# 	input(">>>")
 
 				if what is CATEGORY:
 					if content is CATEGORY_DIGIT:
@@ -644,7 +653,7 @@ def copy_asset_files(app: Sphinx, exc):
 
 	if exc is None:  # build succeeded
 		with importlib_resources.path(sphinx_toolbox.more_autodoc, "regex.css") as cssfile:
-			copy_asset(str(pathlib.Path(cssfile)), str(pathlib.Path(app.outdir) / '_static'))
+			copy_asset(str(pathlib.Path(cssfile)), str(pathlib.Path(app.outdir) / "_static"))
 
 
 regex_parser = HTMLRegexParser()
@@ -671,7 +680,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 			)
 
 	app.add_css_file("regex.css")
-	app.connect('build-finished', copy_asset_files)
+	app.connect("build-finished", copy_asset_files)
 
 	return {
 			"version": __version__,
